@@ -7,7 +7,7 @@
     col <- c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3", "#FF7F00", "#FFFF33",
       "#A65628", "#F781BF", "#999999")
     if(n <= 9) col <- col[1:n]
-    else col <- rainbow(n)
+    else col <- grDevices::rainbow(n)
   }
   
   if(length(col) != n) stop("Number of colors does not match.")
@@ -17,5 +17,5 @@
 
 .get_colors_cont <- function(val, col = NULL) {
   if(is.null(col)) col <- c("#377EB8", "#E41A1C") # blue -> red 
-  rgb(colorRamp(col, space = "Lab")((val-min(val))/(max(val)-min(val)))/255) 
+  grDevices::rgb(grDevices::colorRamp(col, space = "Lab")((val-min(val, na.rm = TRUE)) / (max(val, na.rm = TRUE) - min(val, na.rm = TRUE)))/255) 
 }
